/*
 * vi:ts=4:tw=78:shiftwidth=4:expandtab
 * vim600:fdm=marker
 *
 * bpsf.h  -  useful routines for manipulating BPSF font file
 *
 * Copyright (C) 2004 by ejoy <ejoy@users.sourceforge.net>
 * Begin       : 27-Jul-2004
 * Last Change : 10-May-2006.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser GPL (LGPL) as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program.
 */

#ifndef _BPSF_H
#define _BPSF_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#if defined(__cplusplus)
extern "C" {
#endif

typedef struct {
    char     *m_filename;       /* never freed by user */
    unsigned short    m_unicode_map[65536]; /* index to glyph offset in bitmap
                                               or -1 if no such glyph in font */
    unsigned char     *m_bitmap;        /* raw bitmap font data         */
    unsigned  m_width;         /* font width in bits           */
    unsigned  m_height;        /* font height in bits          */
    unsigned  m_glyph_size;    /* glyph size in bytes          */
    unsigned  m_glyph_count;   /* how many glyphs in this file */
    int       m_use_mmap;      /* whether to use mmap call     */
} bpsf_info;

bpsf_info* bpsf_create();
int bpsf_open(bpsf_info* info, const char* file);
int bpsf_close(bpsf_info* info);
unsigned char* bpsf_index(bpsf_info* info, unsigned short c); /* ucs16 */
unsigned char* bpsf_index_utf8(bpsf_info* info, const unsigned char *utf8);
unsigned char* bpsf_index2(bpsf_info* info, unsigned short c); /* ucs16 */

#if defined(__cplusplus)
}
#endif

#endif /* ifndef _BPSF_H */

